abacusai.prediction_operator_version — AbacusAI documentation

# abacusai.prediction_operator_version

## Classes

`CodeSource` | Code source for python-based custom feature groups and models
`AbstractApiClass` |
`PredictionOperatorVersion` | A prediction operator version.

## Module Contents

class abacusai.prediction_operator_version.CodeSource(client, sourceType=None, sourceCode=None, applicationConnectorId=None, applicationConnectorInfo=None, packageRequirements=None, status=None, error=None, publishingMsg=None, moduleDependencies=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Code source for python-based custom feature groups and models

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - sourceType (str) – The type of the source, one of TEXT, PYTHON, FILE_UPLOAD, or APPLICATION_CONNECTOR

    - sourceCode (str) – If the type of the source is TEXT, the raw text of the function

    - applicationConnectorId (str) – The Application Connector to fetch the code from

    - applicationConnectorInfo (str) – Args passed to the application connector to fetch the code

    - packageRequirements (list) – The pip package dependencies required to run the code

    - status (str) – The status of the code and validations

    - error (str) – If the status is failed, an error message describing what went wrong

    - publishingMsg (dict) – Warnings in the source code

    - moduleDependencies (list) – The list of internal modules dependencies required to run the code

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

  import_as_cell()

    Adds the source code as an unexecuted cell in the notebook.

class abacusai.prediction_operator_version.AbstractApiClass(client, id)
  __eq__(other)

    Return self==value.

  _get_attribute_as_dict(attribute)

class abacusai.prediction_operator_version.PredictionOperatorVersion(client, predictionOperatorId=None, predictionOperatorVersion=None, createdAt=None, updatedAt=None, sourceCode=None, memory=None, useGpu=None, featureGroupIds=None, featureGroupVersions=None, status=None, error=None, codeSource={})

  Bases: `abacusai.return_class.AbstractApiClass`

  A prediction operator version.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - predictionOperatorId (str) – The unique identifier of the prediction operator.

    - predictionOperatorVersion (str) – The unique identifier of the prediction operator version.

    - createdAt (str) – Date and time at which the prediction operator was created.

    - updatedAt (str) – Date and time at which the prediction operator was updated.

    - sourceCode (str) – Python code used to make the prediction operator.

    - memory (int) – Memory in GB specified for the prediction operator version.

    - useGpu (bool) – Whether this prediction operator version is using gpu.

    - featureGroupIds (list) – A list of Feature Group IDs used for initializing.

    - featureGroupVersions (list) – A list of Feature Group version IDs used for initializing.

    - status (str) – The current status of the prediction operator version.

    - error (str) – The error message if the status failed.

    - codeSource (CodeSource) – If a python model, information on the source code.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

  delete()

    Delete a prediction operator version.

    Parameters:

      prediction_operator_version (str) – The unique ID of the prediction operator version.